<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Nico\Nico\Interfaces\AssociationsRepositoryInterface;
use Nico\Nico\Repositories\Presenter\AssociationsItemTransformer;

/**
 * Pubic API controller class.
 */
class AssociationsPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Nico\Associations\Interfaces\AssociationsRepositoryInterface $associations
     *
     * @return type
     */
    public function __construct(AssociationsRepositoryInterface $associations)
    {
        $this->repository = $associations;
        parent::__construct();
    }

    /**
     * Show associations's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $associations = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\AssociationsListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $associations['code'] = 2000;
        return response()->json($associations)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show associations.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $associations = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($associations)) {
            $associations         = $this->itemPresenter($module, new AssociationsItemTransformer);
            $associations['code'] = 2001;
            return response()->json($associations)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
