<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Nico\Nico\Http\Requests\BureauRequest;
use Nico\Nico\Interfaces\BureauRepositoryInterface;
use Nico\Nico\Models\Bureau;

/**
 * Admin API controller class.
 */
class BureauAdminController extends BaseController
{
    /**
     * Initialize bureau controller.
     *
     * @param type BureauRepositoryInterface $bureau
     *
     * @return type
     */
    public function __construct(BureauRepositoryInterface $bureau)
    {
        $this->repository = $bureau;
        parent::__construct();
    }

    /**
     * Display a list of bureau.
     *
     * @return json
     */
    public function index(BureauRequest $request)
    {
        $bureaus  = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\BureauListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $bureaus['code'] = 2000;
        return response()->json($bureaus) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display bureau.
     *
     * @param Request $request
     * @param Model   Bureau
     *
     * @return Json
     */
    public function show(BureauRequest $request, Bureau $bureau)
    {
        $bureau         = $bureau->presenter();
        $bureau['code'] = 2001;
        return response()->json($bureau)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new bureau.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(BureauRequest $request, Bureau $bureau)
    {
        $bureau         = $bureau->presenter();
        $bureau['code'] = 2002;
        return response()->json($bureau)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new bureau.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(BureauRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $bureau          = $this->repository->create($attributes);
            $bureau          = $bureau->presenter();
            $bureau['code']  = 2004;

            return response()->json($bureau)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show bureau for editing.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return json
     */
    public function edit(BureauRequest $request, Bureau $bureau)
    {
        $bureau         = $bureau->presenter();
        $bureau['code'] = 2003;
        return response()-> json($bureau)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the bureau.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return json
     */
    public function update(BureauRequest $request, Bureau $bureau)
    {
        try {

            $attributes = $request->all();

            $bureau->update($attributes);
            $bureau         = $bureau->presenter();
            $bureau['code'] = 2005;

            return response()->json($bureau)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the bureau.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return json
     */
    public function destroy(BureauRequest $request, Bureau $bureau)
    {
        try {
            $t = $bureau->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('nico::bureau.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
