<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Nico\Nico\Interfaces\BureauRepositoryInterface;
use Nico\Nico\Repositories\Presenter\BureauItemTransformer;

/**
 * Pubic API controller class.
 */
class BureauPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Nico\Bureau\Interfaces\BureauRepositoryInterface $bureau
     *
     * @return type
     */
    public function __construct(BureauRepositoryInterface $bureau)
    {
        $this->repository = $bureau;
        parent::__construct();
    }

    /**
     * Show bureau's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $bureaus = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\BureauListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $bureaus['code'] = 2000;
        return response()->json($bureaus)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show bureau.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $bureau = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($bureau)) {
            $bureau         = $this->itemPresenter($module, new BureauItemTransformer);
            $bureau['code'] = 2001;
            return response()->json($bureau)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
