<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Nico\Nico\Http\Requests\CommuneRequest;
use Nico\Nico\Interfaces\CommuneRepositoryInterface;
use Nico\Nico\Models\Commune;

/**
 * Admin API controller class.
 */
class CommuneAdminController extends BaseController
{
    /**
     * Initialize commune controller.
     *
     * @param type CommuneRepositoryInterface $commune
     *
     * @return type
     */
    public function __construct(CommuneRepositoryInterface $commune)
    {
        $this->repository = $commune;
        parent::__construct();
    }

    /**
     * Display a list of commune.
     *
     * @return json
     */
    public function index(CommuneRequest $request)
    {
        $communes  = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\CommuneListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $communes['code'] = 2000;
        return response()->json($communes) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display commune.
     *
     * @param Request $request
     * @param Model   Commune
     *
     * @return Json
     */
    public function show(CommuneRequest $request, Commune $commune)
    {
        $commune         = $commune->presenter();
        $commune['code'] = 2001;
        return response()->json($commune)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new commune.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(CommuneRequest $request, Commune $commune)
    {
        $commune         = $commune->presenter();
        $commune['code'] = 2002;
        return response()->json($commune)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new commune.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(CommuneRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $commune          = $this->repository->create($attributes);
            $commune          = $commune->presenter();
            $commune['code']  = 2004;

            return response()->json($commune)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show commune for editing.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return json
     */
    public function edit(CommuneRequest $request, Commune $commune)
    {
        $commune         = $commune->presenter();
        $commune['code'] = 2003;
        return response()-> json($commune)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the commune.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return json
     */
    public function update(CommuneRequest $request, Commune $commune)
    {
        try {

            $attributes = $request->all();

            $commune->update($attributes);
            $commune         = $commune->presenter();
            $commune['code'] = 2005;

            return response()->json($commune)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the commune.
     *
     * @param Request $request
     * @param Model   $commune
     *
     * @return json
     */
    public function destroy(CommuneRequest $request, Commune $commune)
    {
        try {
            $t = $commune->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('nico::commune.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
