<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Nico\Nico\Interfaces\CommuneRepositoryInterface;
use Nico\Nico\Repositories\Presenter\CommuneItemTransformer;

/**
 * Pubic API controller class.
 */
class CommunePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Nico\Commune\Interfaces\CommuneRepositoryInterface $commune
     *
     * @return type
     */
    public function __construct(CommuneRepositoryInterface $commune)
    {
        $this->repository = $commune;
        parent::__construct();
    }

    /**
     * Show commune's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $communes = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\CommuneListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $communes['code'] = 2000;
        return response()->json($communes)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show commune.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $commune = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($commune)) {
            $commune         = $this->itemPresenter($module, new CommuneItemTransformer);
            $commune['code'] = 2001;
            return response()->json($commune)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
