<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Nico\Nico\Http\Requests\DisciplineRequest;
use Nico\Nico\Interfaces\DisciplineRepositoryInterface;
use Nico\Nico\Models\Discipline;

/**
 * Admin API controller class.
 */
class DisciplineAdminController extends BaseController
{
    /**
     * Initialize discipline controller.
     *
     * @param type DisciplineRepositoryInterface $discipline
     *
     * @return type
     */
    public function __construct(DisciplineRepositoryInterface $discipline)
    {
        $this->repository = $discipline;
        parent::__construct();
    }

    /**
     * Display a list of discipline.
     *
     * @return json
     */
    public function index(DisciplineRequest $request)
    {
        $disciplines  = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\DisciplineListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $disciplines['code'] = 2000;
        return response()->json($disciplines) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display discipline.
     *
     * @param Request $request
     * @param Model   Discipline
     *
     * @return Json
     */
    public function show(DisciplineRequest $request, Discipline $discipline)
    {
        $discipline         = $discipline->presenter();
        $discipline['code'] = 2001;
        return response()->json($discipline)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new discipline.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(DisciplineRequest $request, Discipline $discipline)
    {
        $discipline         = $discipline->presenter();
        $discipline['code'] = 2002;
        return response()->json($discipline)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new discipline.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(DisciplineRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $discipline          = $this->repository->create($attributes);
            $discipline          = $discipline->presenter();
            $discipline['code']  = 2004;

            return response()->json($discipline)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show discipline for editing.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return json
     */
    public function edit(DisciplineRequest $request, Discipline $discipline)
    {
        $discipline         = $discipline->presenter();
        $discipline['code'] = 2003;
        return response()-> json($discipline)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the discipline.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return json
     */
    public function update(DisciplineRequest $request, Discipline $discipline)
    {
        try {

            $attributes = $request->all();

            $discipline->update($attributes);
            $discipline         = $discipline->presenter();
            $discipline['code'] = 2005;

            return response()->json($discipline)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the discipline.
     *
     * @param Request $request
     * @param Model   $discipline
     *
     * @return json
     */
    public function destroy(DisciplineRequest $request, Discipline $discipline)
    {
        try {
            $t = $discipline->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('nico::discipline.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
