<?php

namespace Nico\Nico\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Nico\Nico\Interfaces\DisciplineRepositoryInterface;
use Nico\Nico\Repositories\Presenter\DisciplineItemTransformer;

/**
 * Pubic API controller class.
 */
class DisciplinePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Nico\Discipline\Interfaces\DisciplineRepositoryInterface $discipline
     *
     * @return type
     */
    public function __construct(DisciplineRepositoryInterface $discipline)
    {
        $this->repository = $discipline;
        parent::__construct();
    }

    /**
     * Show discipline's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $disciplines = $this->repository
            ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\DisciplineListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $disciplines['code'] = 2000;
        return response()->json($disciplines)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show discipline.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $discipline = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($discipline)) {
            $discipline         = $this->itemPresenter($module, new DisciplineItemTransformer);
            $discipline['code'] = 2001;
            return response()->json($discipline)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
