<?php

namespace Nico\Nico\Http\Controllers;
use Litepie\Nico\Http\Requests\AssociationsRequest;
use Litepie\Nico\Models\Associations;

trait AssociationsWorkflow {
	
    /**
     * Workflow controller function for associations.
     *
     * @param Model   $associations
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(AssociationsRequest $request, Associations $associations, $step)
    {

        try {

            $associations->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('nico::associations.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/associations/associations/' . $associations->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/associations/associations/' . $associations->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for associations.
     *
     * @param Model   $associations
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Associations $associations, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $associations->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('nico::associations.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.associations.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.associations.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.associations.message', $data)->render();

        }

    }
}