<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\AdminController as BaseController;
use Form;
use Nico\Nico\Http\Requests\BureauRequest;
use Nico\Nico\Interfaces\BureauRepositoryInterface;
use Nico\Nico\Models\Bureau;

/**
 * Admin web controller class.
 */
class BureauAdminController extends BaseController
{
    // use BureauWorkflow;
    /**
     * Initialize bureau controller.
     *
     * @param type BureauRepositoryInterface $bureau
     *
     * @return type
     */
    public function __construct(BureauRepositoryInterface $bureau)
    {
        $this->repository = $bureau;
        parent::__construct();
    }

    /**
     * Display a list of bureau.
     *
     * @return Response
     */
    public function index(BureauRequest $request)
    {
        if ($request->wantsJson()) {
            return $this->getJson($request);
        }
        $this   ->theme->prependTitle(trans('nico::bureau.names').' :: ');
        return $this->theme->of('nico::admin.bureau.index')->render();
    }

    /**
     * Display a list of bureau.
     *
     * @return Response
     */
    public function getJson(BureauRequest $request)
    {
        $pageLimit = $request->input('pageLimit');

        $bureaus  = $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->setPresenter('\\Nico\\Nico\\Repositories\\Presenter\\BureauListPresenter')
                ->scopeQuery(function($query){
                    return $query->orderBy('id','DESC');
                })->paginate($pageLimit);
        $bureaus['recordsTotal']    = $bureaus['meta']['pagination']['total'];
        $bureaus['recordsFiltered'] = $bureaus['meta']['pagination']['total'];
        $bureaus['request']         = $request->all();
        return response()->json($bureaus, 200);

    }

    /**
     * Display bureau.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return Response
     */
    public function show(BureauRequest $request, Bureau $bureau)
    {
        if (!$bureau->exists) {
            return response()->view('nico::admin.bureau.new', compact('bureau'));
        }

        Form::populate($bureau);
        return response()->view('nico::admin.bureau.show', compact('bureau'));
    }

    /**
     * Show the form for creating a new bureau.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BureauRequest $request)
    {

        $bureau = $this->repository->newInstance([]);

        Form::populate($bureau);

        return response()->view('nico::admin.bureau.create', compact('bureau'));

    }

    /**
     * Create new bureau.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BureauRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $bureau          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::bureau.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/bureau/'.$bureau->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show bureau for editing.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return Response
     */
    public function edit(BureauRequest $request, Bureau $bureau)
    {
        Form::populate($bureau);
        return  response()->view('nico::admin.bureau.edit', compact('bureau'));
    }

    /**
     * Update the bureau.
     *
     * @param Request $request
     * @param Model   $bureau
     *
     * @return Response
     */
    public function update(BureauRequest $request, Bureau $bureau)
    {
        try {

            $attributes = $request->all();

            $bureau->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('nico::bureau.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/nico/bureau/'.$bureau->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/bureau/'.$bureau->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the bureau.
     *
     * @param Model   $bureau
     *
     * @return Response
     */
    public function destroy(BureauRequest $request, Bureau $bureau)
    {

        try {

            $t = $bureau->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('nico::bureau.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/nico/bureau/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/nico/bureau/'.$bureau->getRouteKey()),
            ], 400);
        }
    }

}
