<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Nico\Nico\Http\Requests\BureauRequest;
use Nico\Nico\Interfaces\BureauRepositoryInterface;
use Nico\Nico\Models\Bureau;

class BureauUserController extends BaseController
{
    /**
     * Initialize bureau controller.
     *
     * @param type BureauRepositoryInterface $bureau
     *
     * @return type
     */
    public function __construct(BureauRepositoryInterface $bureau)
    {
        $this->repository = $bureau;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Nico\Nico\Repositories\Criteria\BureauUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BureauRequest $request)
    {
        $bureaus = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('nico::bureau.names'));

        return $this->theme->of('nico::user.bureau.index', compact('bureaus'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Bureau $bureau
     *
     * @return Response
     */
    public function show(BureauRequest $request, Bureau $bureau)
    {
        Form::populate($bureau);

        return $this->theme->of('nico::user.bureau.show', compact('bureau'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BureauRequest $request)
    {

        $bureau = $this->repository->newInstance([]);
        Form::populate($bureau);

        $this->theme->prependTitle(trans('nico::bureau.names'));
        return $this->theme->of('nico::user.bureau.create', compact('bureau'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BureauRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $bureau = $this->repository->create($attributes);

            return redirect(trans_url('/user/nico/bureau'))
                -> with('message', trans('messages.success.created', ['Module' => trans('nico::bureau.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Bureau $bureau
     *
     * @return Response
     */
    public function edit(BureauRequest $request, Bureau $bureau)
    {

        Form::populate($bureau);
        $this->theme->prependTitle(trans('nico::bureau.names'));

        return $this->theme->of('nico::user.bureau.edit', compact('bureau'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Bureau $bureau
     *
     * @return Response
     */
    public function update(BureauRequest $request, Bureau $bureau)
    {
        try {
            $this->repository->update($request->all(), $bureau->getRouteKey());

            return redirect(trans_url('/user/nico/bureau'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('nico::bureau.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BureauRequest $request, Bureau $bureau)
    {
        try {
            $this->repository->delete($bureau->getRouteKey());
            return redirect(trans_url('/user/nico/bureau'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('nico::bureau.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
