<?php

namespace Nico\Nico\Http\Controllers;
use Litepie\Nico\Http\Requests\BureauRequest;
use Litepie\Nico\Models\Bureau;

trait BureauWorkflow {
	
    /**
     * Workflow controller function for bureau.
     *
     * @param Model   $bureau
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BureauRequest $request, Bureau $bureau, $step)
    {

        try {

            $bureau->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('nico::bureau.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/bureau/bureau/' . $bureau->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/bureau/bureau/' . $bureau->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for bureau.
     *
     * @param Model   $bureau
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Bureau $bureau, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $bureau->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('nico::bureau.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.bureau.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.bureau.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.bureau.message', $data)->render();

        }

    }
}