<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Nico\Nico\Http\Requests\CommuneRequest;
use Nico\Nico\Interfaces\CommuneRepositoryInterface;
use Nico\Nico\Models\Commune;

class CommuneUserController extends BaseController
{
    /**
     * Initialize commune controller.
     *
     * @param type CommuneRepositoryInterface $commune
     *
     * @return type
     */
    public function __construct(CommuneRepositoryInterface $commune)
    {
        $this->repository = $commune;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Nico\Nico\Repositories\Criteria\CommuneUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(CommuneRequest $request)
    {
        $communes = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('nico::commune.names'));

        return $this->theme->of('nico::user.commune.index', compact('communes'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Commune $commune
     *
     * @return Response
     */
    public function show(CommuneRequest $request, Commune $commune)
    {
        Form::populate($commune);

        return $this->theme->of('nico::user.commune.show', compact('commune'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CommuneRequest $request)
    {

        $commune = $this->repository->newInstance([]);
        Form::populate($commune);

        $this->theme->prependTitle(trans('nico::commune.names'));
        return $this->theme->of('nico::user.commune.create', compact('commune'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CommuneRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $commune = $this->repository->create($attributes);

            return redirect(trans_url('/user/nico/commune'))
                -> with('message', trans('messages.success.created', ['Module' => trans('nico::commune.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Commune $commune
     *
     * @return Response
     */
    public function edit(CommuneRequest $request, Commune $commune)
    {

        Form::populate($commune);
        $this->theme->prependTitle(trans('nico::commune.names'));

        return $this->theme->of('nico::user.commune.edit', compact('commune'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Commune $commune
     *
     * @return Response
     */
    public function update(CommuneRequest $request, Commune $commune)
    {
        try {
            $this->repository->update($request->all(), $commune->getRouteKey());

            return redirect(trans_url('/user/nico/commune'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('nico::commune.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(CommuneRequest $request, Commune $commune)
    {
        try {
            $this->repository->delete($commune->getRouteKey());
            return redirect(trans_url('/user/nico/commune'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('nico::commune.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
