<?php

namespace Nico\Nico\Http\Controllers;
use Litepie\Nico\Http\Requests\CommuneRequest;
use Litepie\Nico\Models\Commune;

trait CommuneWorkflow {
	
    /**
     * Workflow controller function for commune.
     *
     * @param Model   $commune
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CommuneRequest $request, Commune $commune, $step)
    {

        try {

            $commune->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('nico::commune.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/commune/commune/' . $commune->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/commune/commune/' . $commune->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for commune.
     *
     * @param Model   $commune
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Commune $commune, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $commune->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('nico::commune.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.commune.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.commune.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.commune.message', $data)->render();

        }

    }
}