<?php

namespace Nico\Nico\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Nico\Nico\Http\Requests\DisciplineRequest;
use Nico\Nico\Interfaces\DisciplineRepositoryInterface;
use Nico\Nico\Models\Discipline;

class DisciplineUserController extends BaseController
{
    /**
     * Initialize discipline controller.
     *
     * @param type DisciplineRepositoryInterface $discipline
     *
     * @return type
     */
    public function __construct(DisciplineRepositoryInterface $discipline)
    {
        $this->repository = $discipline;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Nico\Nico\Repositories\Criteria\DisciplineUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(DisciplineRequest $request)
    {
        $disciplines = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('nico::discipline.names'));

        return $this->theme->of('nico::user.discipline.index', compact('disciplines'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Discipline $discipline
     *
     * @return Response
     */
    public function show(DisciplineRequest $request, Discipline $discipline)
    {
        Form::populate($discipline);

        return $this->theme->of('nico::user.discipline.show', compact('discipline'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(DisciplineRequest $request)
    {

        $discipline = $this->repository->newInstance([]);
        Form::populate($discipline);

        $this->theme->prependTitle(trans('nico::discipline.names'));
        return $this->theme->of('nico::user.discipline.create', compact('discipline'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(DisciplineRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $discipline = $this->repository->create($attributes);

            return redirect(trans_url('/user/nico/discipline'))
                -> with('message', trans('messages.success.created', ['Module' => trans('nico::discipline.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Discipline $discipline
     *
     * @return Response
     */
    public function edit(DisciplineRequest $request, Discipline $discipline)
    {

        Form::populate($discipline);
        $this->theme->prependTitle(trans('nico::discipline.names'));

        return $this->theme->of('nico::user.discipline.edit', compact('discipline'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Discipline $discipline
     *
     * @return Response
     */
    public function update(DisciplineRequest $request, Discipline $discipline)
    {
        try {
            $this->repository->update($request->all(), $discipline->getRouteKey());

            return redirect(trans_url('/user/nico/discipline'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('nico::discipline.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(DisciplineRequest $request, Discipline $discipline)
    {
        try {
            $this->repository->delete($discipline->getRouteKey());
            return redirect(trans_url('/user/nico/discipline'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('nico::discipline.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
