<?php

namespace Nico\Nico\Http\Controllers;
use Litepie\Nico\Http\Requests\DisciplineRequest;
use Litepie\Nico\Models\Discipline;

trait DisciplineWorkflow {
	
    /**
     * Workflow controller function for discipline.
     *
     * @param Model   $discipline
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(DisciplineRequest $request, Discipline $discipline, $step)
    {

        try {

            $discipline->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('nico::discipline.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/discipline/discipline/' . $discipline->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/discipline/discipline/' . $discipline->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for discipline.
     *
     * @param Model   $discipline
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Discipline $discipline, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $discipline->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('nico::discipline.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.discipline.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.discipline.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('nico::admin.discipline.message', $data)->render();

        }

    }
}