<?php

namespace Nico\Nico\Policies;

use App\User;
use Nico\Nico\Models\Associations;

class AssociationsPolicy
{

    /**
     * Determine if the given user can view the associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function view(User $user, Associations $associations)
    {
        if ($user->canDo('nico.associations.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $associations->user_id;
    }

    /**
     * Determine if the given user can create a associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('nico.associations.create');
    }

    /**
     * Determine if the given user can update the given associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function update(User $user, Associations $associations)
    {
        if ($user->canDo('nico.associations.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $associations->user_id;
    }

    /**
     * Determine if the given user can delete the given associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function destroy(User $user, Associations $associations)
    {
        if ($user->canDo('nico.associations.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $associations->user_id;
    }

    /**
     * Determine if the given user can verify the given associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function verify(User $user, Associations $associations)
    {
        if ($user->canDo('nico.associations.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('nico.associations.verify') 
        && $user->is('manager')
        && $associations->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given associations.
     *
     * @param User $user
     * @param Associations $associations
     *
     * @return bool
     */
    public function approve(User $user, Associations $associations)
    {
        if ($user->canDo('nico.associations.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
