<?php

namespace Nico\Nico\Policies;

use App\User;
use Nico\Nico\Models\Bureau;

class BureauPolicy
{

    /**
     * Determine if the given user can view the bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function view(User $user, Bureau $bureau)
    {
        if ($user->canDo('nico.bureau.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $bureau->user_id;
    }

    /**
     * Determine if the given user can create a bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('nico.bureau.create');
    }

    /**
     * Determine if the given user can update the given bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function update(User $user, Bureau $bureau)
    {
        if ($user->canDo('nico.bureau.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $bureau->user_id;
    }

    /**
     * Determine if the given user can delete the given bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function destroy(User $user, Bureau $bureau)
    {
        if ($user->canDo('nico.bureau.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $bureau->user_id;
    }

    /**
     * Determine if the given user can verify the given bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function verify(User $user, Bureau $bureau)
    {
        if ($user->canDo('nico.bureau.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('nico.bureau.verify') 
        && $user->is('manager')
        && $bureau->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bureau.
     *
     * @param User $user
     * @param Bureau $bureau
     *
     * @return bool
     */
    public function approve(User $user, Bureau $bureau)
    {
        if ($user->canDo('nico.bureau.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
