<?php

namespace Nico\Nico\Policies;

use App\User;
use Nico\Nico\Models\Commune;

class CommunePolicy
{

    /**
     * Determine if the given user can view the commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function view(User $user, Commune $commune)
    {
        if ($user->canDo('nico.commune.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $commune->user_id;
    }

    /**
     * Determine if the given user can create a commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('nico.commune.create');
    }

    /**
     * Determine if the given user can update the given commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function update(User $user, Commune $commune)
    {
        if ($user->canDo('nico.commune.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $commune->user_id;
    }

    /**
     * Determine if the given user can delete the given commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function destroy(User $user, Commune $commune)
    {
        if ($user->canDo('nico.commune.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $commune->user_id;
    }

    /**
     * Determine if the given user can verify the given commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function verify(User $user, Commune $commune)
    {
        if ($user->canDo('nico.commune.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('nico.commune.verify') 
        && $user->is('manager')
        && $commune->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given commune.
     *
     * @param User $user
     * @param Commune $commune
     *
     * @return bool
     */
    public function approve(User $user, Commune $commune)
    {
        if ($user->canDo('nico.commune.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
