<?php

namespace Nico\Nico\Policies;

use App\User;
use Nico\Nico\Models\Discipline;

class DisciplinePolicy
{

    /**
     * Determine if the given user can view the discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function view(User $user, Discipline $discipline)
    {
        if ($user->canDo('nico.discipline.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $discipline->user_id;
    }

    /**
     * Determine if the given user can create a discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('nico.discipline.create');
    }

    /**
     * Determine if the given user can update the given discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function update(User $user, Discipline $discipline)
    {
        if ($user->canDo('nico.discipline.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $discipline->user_id;
    }

    /**
     * Determine if the given user can delete the given discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function destroy(User $user, Discipline $discipline)
    {
        if ($user->canDo('nico.discipline.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $discipline->user_id;
    }

    /**
     * Determine if the given user can verify the given discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function verify(User $user, Discipline $discipline)
    {
        if ($user->canDo('nico.discipline.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('nico.discipline.verify') 
        && $user->is('manager')
        && $discipline->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given discipline.
     *
     * @param User $user
     * @param Discipline $discipline
     *
     * @return bool
     */
    public function approve(User $user, Discipline $discipline)
    {
        if ($user->canDo('nico.discipline.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
