<?php

namespace Nico\Nico\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Associations validator
        \Nico\Nico\Models\Associations::class => \Nico\Nico\Workflow\AssociationsValidator::class,

        // Bind Bureau validator
        \Nico\Nico\Models\Bureau::class => \Nico\Nico\Workflow\BureauValidator::class,

        // Bind Commune validator
        \Nico\Nico\Models\Commune::class => \Nico\Nico\Workflow\CommuneValidator::class,

        // Bind Discipline validator
        \Nico\Nico\Models\Discipline::class => \Nico\Nico\Workflow\DisciplineValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Associations actions
        \Nico\Nico\Models\Associations::class => \Nico\Nico\Workflow\AssociationsAction::class,

        // Bind Bureau actions
        \Nico\Nico\Models\Bureau::class => \Nico\Nico\Workflow\BureauAction::class,

        // Bind Commune actions
        \Nico\Nico\Models\Commune::class => \Nico\Nico\Workflow\CommuneAction::class,

        // Bind Discipline actions
        \Nico\Nico\Models\Discipline::class => \Nico\Nico\Workflow\DisciplineAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Associations notifiers
        \Nico\Nico\Models\Associations::class => \Nico\Nico\Workflow\AssociationsNotifier::class,

        // Bind Bureau notifiers
        \Nico\Nico\Models\Bureau::class => \Nico\Nico\Workflow\BureauNotifier::class,

        // Bind Commune notifiers
        \Nico\Nico\Models\Commune::class => \Nico\Nico\Workflow\CommuneNotifier::class,

        // Bind Discipline notifiers
        \Nico\Nico\Models\Discipline::class => \Nico\Nico\Workflow\DisciplineNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
