<?php

namespace Nico\Nico\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Nico\Nico\Models\Associations;

class AssociationsAction
{
    /**
     * Perform the complete action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */
    public function complete(Associations $associations)
    {
        try {
            $associations->status = 'complete';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */public function verify(Associations $associations)
    {
        try {
            $associations->status = 'verify';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */public function approve(Associations $associations)
    {
        try {
            $associations->status = 'approve';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */public function publish(Associations $associations)
    {
        try {
            $associations->status = 'publish';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */
    public function archive(Associations $associations)
    {
        try {
            $associations->status = 'archive';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Associations $associations
     *
     * @return Associations
     */
    public function unpublish(Associations $associations)
    {
        try {
            $associations->status = 'unpublish';
            return $associations->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
