<?php

namespace Nico\Nico\Workflow;

use Nico\Nico\Models\Associations;
use Validator;

class AssociationsValidator
{

    /**
     * Determine if the given associations is valid for complete status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function complete(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given associations is valid for verify status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function verify(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given associations is valid for approve status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function approve(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given associations is valid for publish status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function publish(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given associations is valid for archive status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function archive(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given associations is valid for unpublish status.
     *
     * @param Associations $associations
     *
     * @return bool / Validator
     */
    public function unpublish(Associations $associations)
    {
        return Validator::make($associations->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
