<?php

namespace Nico\Nico\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Nico\Nico\Models\Bureau;

class BureauAction
{
    /**
     * Perform the complete action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */
    public function complete(Bureau $bureau)
    {
        try {
            $bureau->status = 'complete';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */public function verify(Bureau $bureau)
    {
        try {
            $bureau->status = 'verify';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */public function approve(Bureau $bureau)
    {
        try {
            $bureau->status = 'approve';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */public function publish(Bureau $bureau)
    {
        try {
            $bureau->status = 'publish';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */
    public function archive(Bureau $bureau)
    {
        try {
            $bureau->status = 'archive';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Bureau $bureau
     *
     * @return Bureau
     */
    public function unpublish(Bureau $bureau)
    {
        try {
            $bureau->status = 'unpublish';
            return $bureau->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
