<?php

namespace Nico\Nico\Workflow;

use Nico\Nico\Models\Bureau;
use Validator;

class BureauValidator
{

    /**
     * Determine if the given bureau is valid for complete status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function complete(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given bureau is valid for verify status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function verify(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given bureau is valid for approve status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function approve(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given bureau is valid for publish status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function publish(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given bureau is valid for archive status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function archive(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given bureau is valid for unpublish status.
     *
     * @param Bureau $bureau
     *
     * @return bool / Validator
     */
    public function unpublish(Bureau $bureau)
    {
        return Validator::make($bureau->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
