<?php

namespace Nico\Nico\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Nico\Nico\Models\Commune;

class CommuneAction
{
    /**
     * Perform the complete action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */
    public function complete(Commune $commune)
    {
        try {
            $commune->status = 'complete';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */public function verify(Commune $commune)
    {
        try {
            $commune->status = 'verify';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */public function approve(Commune $commune)
    {
        try {
            $commune->status = 'approve';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */public function publish(Commune $commune)
    {
        try {
            $commune->status = 'publish';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */
    public function archive(Commune $commune)
    {
        try {
            $commune->status = 'archive';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Commune $commune
     *
     * @return Commune
     */
    public function unpublish(Commune $commune)
    {
        try {
            $commune->status = 'unpublish';
            return $commune->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
