<?php

namespace Nico\Nico\Workflow;

use Nico\Nico\Models\Commune;
use Validator;

class CommuneValidator
{

    /**
     * Determine if the given commune is valid for complete status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function complete(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given commune is valid for verify status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function verify(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given commune is valid for approve status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function approve(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given commune is valid for publish status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function publish(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given commune is valid for archive status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function archive(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given commune is valid for unpublish status.
     *
     * @param Commune $commune
     *
     * @return bool / Validator
     */
    public function unpublish(Commune $commune)
    {
        return Validator::make($commune->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
