<?php

namespace Nico\Nico\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Nico\Nico\Models\Discipline;

class DisciplineAction
{
    /**
     * Perform the complete action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */
    public function complete(Discipline $discipline)
    {
        try {
            $discipline->status = 'complete';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */public function verify(Discipline $discipline)
    {
        try {
            $discipline->status = 'verify';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */public function approve(Discipline $discipline)
    {
        try {
            $discipline->status = 'approve';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */public function publish(Discipline $discipline)
    {
        try {
            $discipline->status = 'publish';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */
    public function archive(Discipline $discipline)
    {
        try {
            $discipline->status = 'archive';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Discipline $discipline
     *
     * @return Discipline
     */
    public function unpublish(Discipline $discipline)
    {
        try {
            $discipline->status = 'unpublish';
            return $discipline->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
