<?php

namespace Nico\Nico\Workflow;

use Nico\Nico\Models\Discipline;
use Validator;

class DisciplineValidator
{

    /**
     * Determine if the given discipline is valid for complete status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function complete(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given discipline is valid for verify status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function verify(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given discipline is valid for approve status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function approve(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given discipline is valid for publish status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function publish(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given discipline is valid for archive status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function archive(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given discipline is valid for unpublish status.
     *
     * @param Discipline $discipline
     *
     * @return bool / Validator
     */
    public function unpublish(Discipline $discipline)
    {
        return Validator::make($discipline->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
